<div align="center">
	<a href="https://www.npmjs.com/~canvasjs">
		<img src="https://canvasjs.com/wp-content/uploads/images/logo/canvasjs-logo-240x100.png" alt="CanvasJS"/>
	</a>
</div>

# CanvasJS Angular Charts
CanvasJS Angular Chart Component for creating interactive charts and graphs for your web pages. Library supports a wide range of chart types including bar, line, area, pie, doughnut, etc.

<br/>

<a href="https://canvasjs.com/angular-charts/">
	<img src="https://canvasjs.com/wp-content/uploads/images/npm/angular/angular-charts.jpg" alt="CanvasJS Angular Charts">
</a>

<br/>

## Links
- [Official Website](https://canvasjs.com/)
- [Angular Charts Demo](https://canvasjs.com/angular-charts/)
- [Download CanvasJS](https://canvasjs.com/download-html5-charting-graphing-library/)
- [Angular Charts Integration](https://canvasjs.com/docs/charts/integration/angular/)
- [Chart Documentation](https://canvasjs.com/docs/charts/chart-options/)
- [CanvasJS Support Forum](https://canvasjs.com/forums/)

## Installing CanvasJS Angular Charts
Install CanvasJS Angular Charts package to your Angular app
```
npm install @canvasjs/angular-charts
```
See [npm documentation](https://docs.npmjs.com/) to know more about npm usage.

##### Import Angular Chart Module & register it
Import the Angular Chart module into your Angular application (app.component.ts) & register it.
```
import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterOutlet } from '@angular/router';

import { CanvasJSAngularChartsModule } from '@canvasjs/angular-charts';

@Component({
  selector: 'app-root',
  standalone: true,
    imports: [
      CommonModule,
      RouterOutlet,
      CanvasJSAngularChartsModule
    ],
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
export class AppComponent { }
```

##### Set the chart-options & create chart
Set the chart-options in app.component.ts & use ‘canvasjs-chart’ selector to create chart in app.component.html
```
//app.component.ts
import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterOutlet } from '@angular/router';

import { CanvasJSAngularChartsModule } from '@canvasjs/angular-charts';

@Component({
  selector: 'app-root',
  standalone: true,
  imports: [
    CommonModule,
    RouterOutlet,
    CanvasJSAngularChartsModule
  ],
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
 
export class AppComponent {
  chartOptions = {
    title: {
      text: "Basic Column Chart in Angular"
    },
    data: [{
      type: "column",
      dataPoints: [
        { label: "Apple",  y: 10  },
        { label: "Orange", y: 15  },
        { label: "Banana", y: 25  },
        { label: "Mango",  y: 30  },
        { label: "Grape",  y: 28  }
      ]
    }]                
  };
}
  
  
//app.component.html
<div>
    <canvasjs-chart [options]="chartOptions"></canvasjs-chart>
</div>
```

<br/>

<a href="https://canvasjs.com/angular-charts/column-with-numeric-axis/"><img src="https://canvasjs.com/wp-content/uploads/images/npm/angular/angular-column-chart.png" alt="Angular Column Chart"></a>

<br/>

#### Angular Synchronized Charts
<a href="https://canvasjs.com/angular-charts/synchronized-chart/"><img src="https://canvasjs.com/wp-content/uploads/images/npm/angular/angular-synchronized-charts.gif" alt="Angular Synchronized Charts"></a>

<br/>

#### Angular Animated Charts
<a href="https://canvasjs.com/angular-charts/chart-with-animation/"><img src="https://canvasjs.com/wp-content/uploads/images/npm/angular/angular-animated-pie-chart.gif" alt="Angular Animated Pie Chart"></a>

<br/>

#### Angular Chart with Zooming / Panning
<a href="https://canvasjs.com/angular-charts/chart-zoom-pan/"><img src="https://canvasjs.com/wp-content/uploads/images/npm/angular/angular-charts-zoom-pan.gif" alt="Angular Chart with Zooming / Panning"></a>